Crate polimec_common

Modules

credentials
migration_types

Structs

Assets
A Vec of Assets.
Location
A relative path between state-bearing consensus systems.

Enums

SendError
Error result value when attempting to send an XCM message.

Constants

PLMC_DECIMALS
PLMC_FOREIGN_ID
USD_DECIMALS
USD_UNIT

Traits

ProvideAssetPrice
ReleaseSchedule
A release schedule over a fungible. This allows a particular fungible to have release limits applied to it.
SendXcm
Utility for sending an XCM message to a given location.

Type Aliases

QueryId
An identifier for a query.
SendResult
Result value when attempting to send an XCM message.
Xcm
The basic concrete type of Xcm, which doesn’t make any assumptions about the format of a call other than it is pre-encoded.
XcmHash
A hash type for identifying messages.